<?php
//automatically generated userdata.inc.php for Froxlor
$sql['host']='localhost';
$sql['user']='froxlor';
$sql['password']='CD-Archiv';
$sql['db']='froxlor';
$sql_root[0]['caption']='Default';
$sql_root[0]['host']='localhost';
$sql_root[0]['user']='root';
$sql_root[0]['password']='3Q@r2020';
?>
