<article class="install bradius">
	<header class="dark">
		<img src="../templates/{$theme}/assets/img/logo.png" alt="Froxlor Server Management Panel" />
	</header>

	<section class="installsec">
		<h2>{$pagetitle}</h2>
			{$pagecontent}
		{$pagenavigation}
	</section>
</article>
