$header
<div class="messagewrapper">
	<div class="neutralcontainer bradius">
		<div class="neutraltitle">{$lng['menue']['mysql']['mysql']}</div>
		<div class="neutral">{$lng['mysql']['description']}</div>
	</div>
</div>
$footer
