<!DOCTYPE html>
<html lang="en">
<head>
	<meta charset="utf-8" />
	<meta http-equiv="Default-Style" content="text/css" />
	<!--[if lt IE 9]><script src="../js/html5shiv.min.js"></script><![endif]-->
	<link href="templates/assets/css/install.css" rel="stylesheet" type="text/css" />
	<!--[if IE]><link rel="stylesheet" href="../templates/{$theme}/css/main_ie.css" type="text/css" /><![endif]-->
	<link href="templates/assets/img/favicon.ico" rel="icon" type="image/x-icon" />
	<title>Froxlor Server Management Panel - Installation</title>
</head>
<body>
	<div class="installsec">
