<div class="messagewrapperfull" class="phperror">
	<div class="warningcontainer bradius">
		<div class="warningtitle">PHP warning/error</div>
		<div class="warning">
			<p><TEXT></p>
			<p>&nbsp;</p>
			<pre class="overflow"><DEBUG></pre>
			<p>&nbsp;</p>
		</div>
	</div>
</div>
