{$lng['panel']['search']}:&nbsp;
<select name="searchfield">
{$fieldoptions}
</select>&nbsp;
<input type="text" name="searchtext" class="searchtext" value="{$searchtext}" />&nbsp;
<input type="submit" name="Go" value="Go" class="submitsearch" />
<input type="reset" name="Reset" value="Reset" class="resetsearch" />
