<!DOCTYPE html>
<html lang="en">
<head>
	<meta charset="utf-8" />
	<meta http-equiv="Default-Style" content="text/css" />
	<link rel="stylesheet" href="../templates/Sparkle/assets/css/main.css" />
	<!--[if IE]><link rel="stylesheet" href="../templates/Sparkle/assets/css/main_ie.css" /><![endif]-->
	<!--[if lt IE 9]><script src="js/html5shiv.min.js"></script><![endif]-->
	<link href="../templates/Sparkle/assets/img/favicon.ico" rel="icon" type="image/x-icon" />
	<title>Froxlor Server Management Panel - Installation</title>
</head>
<body>
<div class="loginpage">
	
	<article class="login bradius">
		<header class="dark">
			<img src="../templates/Sparkle/assets/img/logo.png" alt="Froxlor Server Management Panel" />
		</header>

		<section class="loginsec">
			<h2>Welcome to Froxlor</h2>
			<p>It seems that Froxlor has already been configured.</p>
			<p>Click on the link below to go to the login page.</p>
			<p>&nbsp;</p>
			<aside class="right">
				<a href="../index.php" title="Click to go to the login page">Go to login</a>
			</aside>
		</section>

	</article>

</div>
<footer>
	<span>
		Froxlor &copy; 2009-<CURRENT_YEAR> by <a href="http://www.froxlor.org/" rel="external">the Froxlor Team</a>
	</span>
</footer>
</body>
</html>
