<div class="pushbot">
	<textarea class="shell" rows="1" readonly>{$distro_editor} {$realname}</textarea>
	<textarea class="filecontent" rows="<if $numbrows <=20 >{$numbrows}<else>21</if>" readonly>{$file_content}</textarea>
</div>
