<section>
	<table class="full">
		<tr>
			<th><strong>{$dt}&nbsp;{$lng['ticket']['by']}&nbsp;{$by}&nbsp;({$status})</strong></th>
		</tr>
		<tr>
			<td>{$subject}</td>
		</tr>
		<tr>
			<td>{$message}</td>
		</tr>
	</table>
	<br />
</section>
<br />
