<tr>
	<td class="formlabeltd">
		<label for="{$fieldname}"><strong>{$label}</strong>{$mandatory}:
		<if $desc != ''>
			<br /><small>{$desc}</small>
		</if>
		</label>
	</td>
	<td>
		{$data_field}
	</td>
</tr>
