<tr class="section">
	<th>
		{$title}
	</th>
	<th class="right nolbr">
		<input type="reset" value="{$lng['panel']['cancel']}" class="historyback" />
		<input type="submit" value="{$lng['panel']['save']}" />
	</th>
</tr>
