<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">

    <title>AWStats for {SITE_DOMAIN}</title>
</head>

<frameset cols="*" rows="45,*" frameborder=0>
    <frame id="topFrame" name="topFrame" noresize="noresize" scrolling="no" src="nav.html" title="topFrame">
    <frame id="mainFrame" name="mainFrame" src="current/awstats.{SITE_DOMAIN}.html" title="mainFrame">

    <noframes>
        <body>
        </body>
    </noframes>
</frameset>
</html>
