<tr>
	<td class="field_name_border_left" colspan="10"><strong>{$customer} (<a href="{$linker->getLink(array('section' => 'customers', 'page' => 'customers', 'action' => 'su', 'id' => $customerid))}" rel="external">{$customerloginname}</a>)</strong></td>
</tr>
