<tfoot>
	<tr>
		<td colspan="2" class="right">
			<input type="reset" value="{$lng['panel']['cancel']}" class="historyback" />
			<input type="submit" value="{$lng['panel']['save']}" />
		</td>
	</tr>
</tfoot>
