<?php

/**
 * This file is part of the Froxlor project.
 * Copyright (c) 2003-2009 the SysCP Team (see authors).
 * Copyright (c) 2010 the Froxlor Team (see authors).
 *
 * For the full copyright and license information, please view the COPYING
 * file that was distributed with this source code. You can also view the
 * COPYING file online at http://files.froxlor.org/misc/COPYING.txt
 *
 * @copyright  (c) the authors
 * @author     Florian Lippert <flo@syscp.org> (2003-2009)
 * @author     Froxlor team <team@froxlor.org> (2010-)
 * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
 * @package    Functions
 *
 */

if(!defined('USR_ACTION'))
	define('USR_ACTION', '10');
if(!defined('RES_ACTION'))
	define('RES_ACTION', '20');
if(!defined('ADM_ACTION'))
	define('ADM_ACTION', '30');
if(!defined('CRON_ACTION'))
	define('CRON_ACTION', '40');
if(!defined('LOGIN_ACTION'))
	define('LOGIN_ACTION', '50');
if(!defined('LOG_ERROR'))
	define('LOG_ERROR', '99');
