<a href="{$baseurl}&amp;sortfield={$fieldname}&amp;sortorder=desc">
	<img src="templates/{$theme}/assets/img/icons/up.png" alt="" />
</a>
<a href="{$baseurl}&amp;sortfield={$fieldname}&amp;sortorder=asc">
	<img src="templates/{$theme}/assets/img/icons/down.png" alt="" />
</a>
