$header
	<article>
		<header>
			<h2>
				<img src="templates/{$theme}/assets/img/icons/traffic_big.png" alt="{$lng['admin']['traffic']}" />&nbsp;{$lng['admin']['traffic']} &nbsp;
			</h2>
		</header>
		{$stats_tables}
	</article>
$footer
